Django Grappelli
================
.. image:: https://api.travis-ci.org/sehmaschine/django-grappelli.svg
    :target: https://travis-ci.org/sehmaschine/django-grappelli

.. image:: https://img.shields.io/pypi/dm/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

.. image:: https://readthedocs.org/projects/django-grappelli/badge/?version=latest
    :target: http://django-grappelli.readthedocs.org/en/latest/?badge=latest

.. image:: https://img.shields.io/pypi/v/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

.. image:: https://img.shields.io/pypi/l/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

**A jazzy skin for the Django admin interface**.

Grappelli is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

Code
----

https://github.com/sehmaschine/django-grappelli

Website
-------

http://www.grappelliproject.com

Documentation
-------------

http://readthedocs.org/docs/django-grappelli/

Releases
--------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.**

* Grappelli 2.8.2 (September 28th, 2016): Compatible with Django 1.9
* Grappelli 2.7.3 (January 11th, 2016): Compatible with Django 1.8
* Grappelli 2.6.5 (May 28th, 2015): Compatible with Django 1.7

Current development branches:

* Grappelli 2.8.3 (Development version for Django 1.9, see branch Stable/2.8.x)
* Grappelli 2.7.4 (Development version for Django 1.8, see branch Stable/2.7.x)
* Grappelli 2.6.6 (Development version for Django 1.7, see branch Stable/2.6.x)

Older versions are available at GitHub, but are not supported anymore.
Support for 2.6.x and 2.7.x is limited to security issues and very important bugfixes.
